#C XRLE Pos=-2,-9
#C A 3-cell pattern runs chaotically, with average density about 25%,
#C until about gen 757537.  Then an iceball forms, which slowly grows,
#C filling the torus completely in gen 757703.
#T 5678/25678:T24,24
#M
2o$2bo!
