#C Emulation of Langton's Ant using a von Neumann CA
#C
#C http://en.wikipedia.org/wiki/Langton's_ant
#C
#C extra states are used to code the ant's current direction:
#C
#C -----------------------------empty squares---------------------
#C 0 : black
#C 1 : white
#C ----------------------------------------------ant is here------
#C 6 : north, black
#C 7 : east, black
#C 8 : south, black
#C 9 : west, black
#C 2 : ant is facing north on a white square
#C 3 : east, white
#C 4 : south, white
#C 5 : west, white
#C ---------------------------------------------------------------
#C
#U langton-ant.r
#P
5
